@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2022, by Samuel Williams.
+# Copyright, 2018-2025, by Samuel Williams.
 
-require_relative 'config'
-require 'rspec/core/formatters'
+require_relative "config"
+require "rspec/core/formatters"
 
 $covered = Covered::Config.load
 
@@ -12,7 +12,7 @@ module Covered
 	module RSpec
 		module Policy
 			def load_spec_files
-				$covered.enable
+				$covered.start
 				
 				super
 			end
@@ -33,7 +33,7 @@ if $covered.record?
 
 	RSpec.configure do |config|
 		config.after(:suite) do
-			$covered.disable
+			$covered.finish
 			$covered.call(config.output_stream)
 		end
 	end
